{% extends "layout.html" %}

{% block page_title %}Forbidden{% endblock %}

{% block content %}
<div class="jumbotron">
    <div class="text-center">
        <h1>403</h1>
        <p>Sorry, you might not have the necessary permissions to access this page.</p>
        <!-- p>Want to <a href="{{ url_for('index') }}">go home</a> instead?</p -->
    </div>
</div>
{% endblock %}
