{% extends 'admin/model/list.html' %}
{% block body %}
  {{ super() }}
{% endblock %}
{% block list_row_actions %}
  <div class="profile-navbar">
    <div class="profile-subnav">
      {{ super() }}
      {% if row.orcid %}
      <div class="profile-subnav-content">
        <a class="icon" href="{{ url_for('section', user_id=row.id, section_type='EMP', url=request.url) }}"
           title="Employment">
          <span class="fa fa-briefcase glyphicon glyphicon-briefcase icon"></span>
        </a>
        <a class="icon" href="{{ url_for('section', user_id=row.id, section_type='EDU', url=request.url) }}"
           title="Education">
          <span class="fa fa-graduation-cap glyphicon glyphicon-education icon"></span>
        </a>
        <a class="icon" href="{{ url_for('section', user_id=row.id, section_type='FUNDING', url=request.url) }}"
           title="Funding">
          <span class="fa fa-money glyphicon glyphicon-money icon"></span>
        </a>
        <a class="icon" href="{{ url_for('section', user_id=row.id, section_type='PRR', url=request.url) }}"
           title="Peer Review Record">
          <span class="fa fa-users"></span>
        </a>
        <a class="icon" href="{{ url_for('section', user_id=row.id, section_type='WOR', url=request.url) }}"
           title="Work Record">
          <span class="fa fa-print"></span>
        </a>
        <a class="icon" href="{{ url_for('section', user_id=row.id, section_type='RUR', url=request.url) }}"
           title="Researcher Url Record">
          <span class="fa fa-at"></span>
        </a>
        <a class="icon" href="{{ url_for('section', user_id=row.id, section_type='ONR', url=request.url) }}"
           title="Other Name Record">
          <span class="fa fa-user-plus"></span>
        </a>
        <a class="icon" href="{{ url_for('section', user_id=row.id, section_type='KWR', url=request.url) }}"
           title="Keyword Record">
          <span class="fa fa-key"></span>
        </a>
      </div>
      {% endif %}
    </div>
  </div>
{% endblock %}
