/* Sticky footer styles
-------------------------------------------------- */
html {
  min-height: 100%;
}
body {
  /* Margin bottom by footer height */
  margin-bottom: 0px;
}
.footer {
  bottom: 0;
  width: 100%;
  /* Set the fixed height of the footer here */
  height: auto;
  background-color: #000;
  position: fixed;

}


/* Custom page CSS
-------------------------------------------------- */
/* Not required for template or sticky footer method. */

/* .container { */
/*   width: auto; */
/*   max-width: 680px; */
/*   padding: 0 15px; */
/* } */
